@@ -5,6 +5,7 @@
 */
 
 #include "searchpatternwarning.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLocalizedString>
 
@@ -12,6 +13,7 @@ using namespace KMail;
 SearchPatternWarning::SearchPatternWarning(QWidget *parent)
     : KMessageWidget(parent)
 {
+    setPosition(KMessageWidget::Header);
     setVisible(false);
     setCloseButtonVisible(true);
     setMessageType(Information);
@@ -22,7 +24,7 @@ SearchPatternWarning::~SearchPatternWarning() = default;
 
 void SearchPatternWarning::setError(const QStringList &lstError)
 {
-    setText(i18n("Search failed some errors were found: <ul><li>%1</li></ul>", lstError.join(QLatin1String("</li><li>"))));
+    setText(i18n("Search failed some errors were found: <ul><li>%1</li></ul>", lstError.join("</li><li>"_L1)));
 }
 
 void SearchPatternWarning::showWarningPattern(const QStringList &lstError)
